//
//  YLDemoFourViewController.m
//  PieTouch
//
//  Created by Kemal Taskin on 11/22/12.
//  Copyright (c) 2012 Yakamoz Labs. All rights reserved.
//

#import "YLDemoFourViewController.h"
#import "UIColor-Expanded.h"
#import <PieTouch/PieTouch.h>
#import <QuartzCore/QuartzCore.h>

@interface YLDemoFourViewController () {
    NSMutableArray *_sliceValues;
    NSMutableArray *_sliceColors;
}

@end

@implementation YLDemoFourViewController

@synthesize chartView = _chartView;
@synthesize button1 = _button1;
@synthesize button2 = _button2;
@synthesize button3 = _button3;
@synthesize button4 = _button4;
@synthesize label1 = _label1;
@synthesize label2 = _label2;
@synthesize label3 = _label3;
@synthesize label4 = _label4;

- (id)init {
    self = [super initWithNibName:@"YLDemoFourViewController" bundle:nil];
    if(self) {
        self.title = @"Demo 4";
        
        _sliceValues = [[NSMutableArray alloc] initWithCapacity:4];
        [_sliceValues addObject:[NSNumber numberWithInt:450]];
        [_sliceValues addObject:[NSNumber numberWithInt:320]];
        [_sliceValues addObject:[NSNumber numberWithInt:210]];
        [_sliceValues addObject:[NSNumber numberWithInt:105]];
        
        _sliceColors = [[NSMutableArray alloc] initWithCapacity:4];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B33131"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"71B232"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"3172B6"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"6E31B2"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B434AF"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B53071"]];
    }
    
    return self;
}

- (void)dealloc {
    [_chartView release];
    [_button1 release];
    [_button2 release];
    [_button3 release];
    [_button4 release];
    [_label1 release];
    [_label2 release];
    [_label3 release];
    [_label4 release];
    [_sliceValues release];
    [_sliceColors release];
    
    [super dealloc];
}

- (void)viewDidLoad {
    [super viewDidLoad];
 
    [_chartView setPieBackgroundColor:[UIColor colorWithHexString:@"999999"]];
    [_chartView setPieBorderColor:[UIColor colorWithWhite:0.0 alpha:0.5]];
    [_chartView setInnerPieBackgroundColor:[UIColor colorWithHexString:@"333333"]];
    [_chartView setPieBorderWidth:4.0];
    [_chartView setTextShadowColor:[UIColor blackColor]];
    [_chartView setTextFont:[UIFont boldSystemFontOfSize:20]];
    [_chartView setInnerRadiusOffset:0.4];
    [_chartView setSelectionStyle:kSelectionStyleNoAnimation];
    [_chartView setLabelStyle:kLabelStyleValue];
    [_chartView setStartAngle:90];
    [_chartView reloadData];
    
    [_button1 setBackgroundColor:[_sliceColors objectAtIndex:0]];
    [_button2 setBackgroundColor:[_sliceColors objectAtIndex:1]];
    [_button3 setBackgroundColor:[_sliceColors objectAtIndex:2]];
    [_button4 setBackgroundColor:[_sliceColors objectAtIndex:3]];
    
    NSArray *buttons = [NSArray arrayWithObjects:_button1, _button2, _button3, _button4, nil];
    for(UIButton *b in buttons) {
        b.layer.cornerRadius = 2.0;
    }
    
    [_label1 setText:[NSString stringWithFormat:@"%d%% - Working", (int)([_chartView normalizedValueForSliceAtIndex:0] * 100)]];
    [_label2 setText:[NSString stringWithFormat:@"%d%% - Meetings", (int)([_chartView normalizedValueForSliceAtIndex:1] * 100)]];
    [_label3 setText:[NSString stringWithFormat:@"%d%% - Eating", (int)([_chartView normalizedValueForSliceAtIndex:2] * 100)]];
    [_label4 setText:[NSString stringWithFormat:@"%d%% - Traveling", (int)([_chartView normalizedValueForSliceAtIndex:3] * 100)]];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation {
    if(UIInterfaceOrientationIsPortrait(toInterfaceOrientation) &&
       toInterfaceOrientation == UIInterfaceOrientationPortraitUpsideDown) {
        return NO;
    }
    
    return YES;
}

- (BOOL)shouldAutorotate {
    return YES;
}

- (NSUInteger)supportedInterfaceOrientations {
    return UIInterfaceOrientationMaskAllButUpsideDown;
}

- (void)willRotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation duration:(NSTimeInterval)duration {
    if(UIInterfaceOrientationIsPortrait(toInterfaceOrientation)) {
        [_chartView setTextFont:[UIFont boldSystemFontOfSize:20]];
    } else {
        [_chartView setTextFont:[UIFont boldSystemFontOfSize:10]];
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}


#pragma mark -
#pragma mark YLPieChartDataSource Methods
- (NSUInteger)numberOfSlicesInPieChartView:(YLPieChartView *)pieChartView {
    return _sliceValues.count;
}

- (CGFloat)pieChartView:(YLPieChartView *)pieChartView valueForSliceAtIndex:(NSUInteger)index {
    return [[_sliceValues objectAtIndex:index] floatValue];
}

- (UIColor *)pieChartView:(YLPieChartView *)pieChartView colorForSliceAtIndex:(NSUInteger)index {
    return [_sliceColors objectAtIndex:index];
}

#pragma mark -
#pragma mark YLPieChartDelegate Methods
- (void)pieChartView:(YLPieChartView *)pieChartView willSelectSliceAtIndex:(NSUInteger)index {
    
}

- (void)pieChartView:(YLPieChartView *)pieChartView didSelectSliceAtIndex:(NSUInteger)index {
    NSLog(@"Did select slice: %d", index);
    UIButton *b = nil;
    if(index == 0) {
        b = _button1;
    } else if(index == 1) {
        b = _button2;
    } else if(index == 2) {
        b = _button3;
    } else if(index == 3) {
        b = _button4;
    }
    
    if(b) {
        b.layer.borderColor = [UIColor whiteColor].CGColor;
        b.layer.borderWidth = 2.0;
    }
}

- (void)pieChartView:(YLPieChartView *)pieChartView willDeselectSliceAtIndex:(NSUInteger)index {
    
}

- (void)pieChartView:(YLPieChartView *)pieChartView didDeselectSliceAtIndex:(NSUInteger)index {
    NSLog(@"Did deselect slice: %d", index);
    UIButton *b = nil;
    if(index == 0) {
        b = _button1;
    } else if(index == 1) {
        b = _button2;
    } else if(index == 2) {
        b = _button3;
    } else if(index == 3) {
        b = _button4;
    }
    
    if(b) {
        b.layer.borderColor = nil;
        b.layer.borderWidth = 0;
    }
}


@end
