//
//  YLDemoOneViewController.m
//  PieTouch
//
//  Created by Kemal Taskin on 11/22/12.
//  Copyright (c) 2012 Yakamoz Labs. All rights reserved.
//

#import "YLDemoOneViewController.h"
#import "UIColor-Expanded.h"
#import <PieTouch/PieTouch.h>
#import <QuartzCore/QuartzCore.h>

@interface YLDemoOneViewController () {
    NSMutableArray *_sliceValues;
}

- (void)reloadData;

@end

@implementation YLDemoOneViewController

@synthesize tableView = _tableView;

- (id)init {
    self = [super initWithNibName:@"YLDemoOneViewController" bundle:nil];
    if(self) {
        self.title = @"Demo 1";
    
        UIBarButtonItem *refresh = [[[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemRefresh
                                                                                  target:self
                                                                                  action:@selector(reloadData)] autorelease];
        self.navigationItem.rightBarButtonItem = refresh;

        _sliceValues = [[NSMutableArray alloc] init];
        for(int i = 0; i < 20; ++i) {
            [_sliceValues addObject:[NSNumber numberWithInt:(arc4random() % 80 + 10)]];
        }
    }
    
    return self;
}

- (void)dealloc {
    [_tableView release];
    [_sliceValues release];
    
    [super dealloc];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    _tableView.backgroundColor = [UIColor colorWithWhite:0.9 alpha:1.0];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation {
    if(UIInterfaceOrientationIsPortrait(toInterfaceOrientation) &&
       toInterfaceOrientation == UIInterfaceOrientationPortraitUpsideDown) {
        return NO;
    }
    
    return YES;
}

- (BOOL)shouldAutorotate {
    return YES;
}

- (NSUInteger)supportedInterfaceOrientations {
    return UIInterfaceOrientationMaskAllButUpsideDown;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}


#pragma mark -
#pragma mark Private Methods
- (void)reloadData {
    [_sliceValues removeAllObjects];
    for(int i = 0; i < 20; ++i) {
        [_sliceValues addObject:[NSNumber numberWithInt:(arc4random() % 80 + 10)]];
    }
    
    [self.tableView reloadData];
}


#pragma mark -
#pragma mark UITableViewDataSource Methods
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return _sliceValues.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *CellIdentifier = @"CellIdentifier";
    
    UITableViewCell *cell = [self.tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if(cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
        int h = cell.frame.size.height - 2;
        
        YLPieSliceChartView *chart = [[[YLPieSliceChartView alloc] initWithFrame:CGRectMake(0, 0, h, h)] autorelease];
        chart.backgroundColor = [UIColor colorWithWhite:0.9 alpha:1.0];
        chart.pieChartView.backgroundColor = [UIColor colorWithWhite:0.9 alpha:1.0];
        chart.pieChartView.innerRadiusOffset = 0.4;
        chart.pieChartView.padding = 5;
        chart.pieChartView.innerPieBackgroundColor = [UIColor whiteColor];
        chart.pieChartView.pieBackgroundColor = [UIColor colorWithRed:0.7529 green:0.8706 blue:0.9686 alpha:1.0];
        chart.pieChartView.pieBorderColor = [UIColor colorWithWhite:0.0 alpha:0.8];
        chart.pieChartView.pieBorderWidth = 2.0;
        chart.pieChartView.showTextLabels = NO;
        chart.sliceColor = [UIColor colorWithHexString:@"23aae2"];
        cell.accessoryView = chart;
        
        cell.textLabel.textColor = [UIColor colorWithWhite:0.2 alpha:1.0];
    }
    
    YLPieSliceChartView *chart = (YLPieSliceChartView *)[cell accessoryView];
    if(chart) {
        chart.sliceValue = ([[_sliceValues objectAtIndex:indexPath.row] floatValue] / 100.0);
    }
    cell.textLabel.text = [NSString stringWithFormat:@"Value %d - %d%%", (indexPath.row + 1), [[_sliceValues objectAtIndex:indexPath.row] intValue]];
    
    return cell;
}

#pragma mark -
#pragma mark UITableViewDelegate Methods
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [self.tableView deselectRowAtIndexPath:indexPath animated:YES];
}

- (void)tableView:(UITableView *)tableView willDisplayCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath {
    cell.backgroundColor = [UIColor colorWithWhite:0.9 alpha:1.0];
    
    YLPieSliceChartView *chart = (YLPieSliceChartView *)[cell accessoryView];
    if(chart) {
        [chart reloadDataAnimated:NO];
    }
}

@end
