//
//  YLDemoTwoViewController.m
//  PieTouch
//
//  Created by Kemal Taskin on 11/22/12.
//  Copyright (c) 2012 Yakamoz Labs. All rights reserved.
//

#import "YLDemoTwoViewController.h"
#import "UIColor-Expanded.h"
#import <PieTouch/PieTouch.h>

@interface YLDemoTwoViewController () {
    NSMutableArray *_sliceValues;
    NSMutableArray *_sliceColors;
}

- (void)addButtonTapped;
- (void)removeButtonTapped;
- (void)clearButtonTapped;

@end

@implementation YLDemoTwoViewController

@synthesize chartView = _chartView;
@synthesize addButton = _addButton;
@synthesize removeButton = _removeButton;
@synthesize clearButton = _clearButton;

- (id)init {
    self = [super initWithNibName:@"YLDemoTwoViewController" bundle:nil];
    if(self) {
        self.title = @"Demo 2";
        
        _sliceValues = [[NSMutableArray alloc] init];
        for(int i = 0; i < 10; ++i) {
            [_sliceValues addObject:[NSNumber numberWithInt:20]];
        }
        
        _sliceColors = [[NSMutableArray alloc] init];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B33131"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B66F2D"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B6B330"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"71B232"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"33B22D"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"31B272"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"2DB5B5"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"3172B6"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"3232B6"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"6E31B2"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B434AF"]];
        [_sliceColors addObject:[UIColor colorWithHexString:@"B53071"]];
    }
    
    return self;
}

- (void)dealloc {
    [_chartView release];
    [_addButton release];
    [_removeButton release];
    [_clearButton release];
    [_sliceValues release];
    [_sliceColors release];
    
    [super dealloc];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [_addButton addTarget:self action:@selector(addButtonTapped) forControlEvents:UIControlEventTouchUpInside];
    [_addButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    [_addButton setBackgroundImage:[UIImage imageNamed:@"b1.png"] forState:UIControlStateNormal];
    [_addButton setBackgroundImage:[UIImage imageNamed:@"b1_high.png"] forState:UIControlStateHighlighted];
    
    [_removeButton addTarget:self action:@selector(removeButtonTapped) forControlEvents:UIControlEventTouchUpInside];
    [_removeButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    [_removeButton setBackgroundImage:[UIImage imageNamed:@"b1.png"] forState:UIControlStateNormal];
    [_removeButton setBackgroundImage:[UIImage imageNamed:@"b1_high.png"] forState:UIControlStateHighlighted];
    
    [_clearButton addTarget:self action:@selector(clearButtonTapped) forControlEvents:UIControlEventTouchUpInside];
    [_clearButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    [_clearButton setBackgroundImage:[UIImage imageNamed:@"b2.png"] forState:UIControlStateNormal];
    [_clearButton setBackgroundImage:[UIImage imageNamed:@"b2_high.png"] forState:UIControlStateHighlighted];
    
    [_chartView setPieBackgroundColor:[UIColor colorWithHexString:@"999999"]];
    [_chartView setPieBorderColor:[UIColor colorWithWhite:0.0 alpha:0.5]];
    [_chartView setInnerPieBackgroundColor:[UIColor colorWithHexString:@"333333"]];
    [_chartView setPieBorderWidth:4.0];
    [_chartView setTextShadowColor:[UIColor blackColor]];
    [_chartView setTextFont:[UIFont boldSystemFontOfSize:20]];
    [_chartView setInnerRadiusOffset:0.5];
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    
    [_chartView reloadData];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation {
    if(UIInterfaceOrientationIsPortrait(toInterfaceOrientation) &&
       toInterfaceOrientation == UIInterfaceOrientationPortraitUpsideDown) {
        return NO;
    }
    
    return YES;
}

- (BOOL)shouldAutorotate {
    return YES;
}

- (NSUInteger)supportedInterfaceOrientations {
    return UIInterfaceOrientationMaskAllButUpsideDown;
}

- (void)willRotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation duration:(NSTimeInterval)duration {
    if(UIInterfaceOrientationIsPortrait(toInterfaceOrientation)) {
        [_chartView setTextFont:[UIFont boldSystemFontOfSize:20]];
    } else {
        [_chartView setTextFont:[UIFont boldSystemFontOfSize:10]];
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}


#pragma mark -
#pragma mark Private Methods
- (void)addButtonTapped {
    [_sliceValues addObject:[NSNumber numberWithInt:20]];
    [_chartView reloadData];
}

- (void)removeButtonTapped {
    if(_sliceValues.count > 0) {
        [_sliceValues removeObjectAtIndex:0];
        [_chartView reloadData];
    }
}

- (void)clearButtonTapped {
    if(_sliceValues.count > 0) {
        [_sliceValues removeAllObjects];
        [_chartView reloadData];
    }
}


#pragma mark -
#pragma mark YLPieChartDataSource Methods
- (NSUInteger)numberOfSlicesInPieChartView:(YLPieChartView *)pieChartView {
    return _sliceValues.count;
}

- (CGFloat)pieChartView:(YLPieChartView *)pieChartView valueForSliceAtIndex:(NSUInteger)index {
    return [[_sliceValues objectAtIndex:index] floatValue];
}

- (UIColor *)pieChartView:(YLPieChartView *)pieChartView colorForSliceAtIndex:(NSUInteger)index {
    if(index < _sliceColors.count) {
        return [_sliceColors objectAtIndex:index];
    }
    
    return nil;
}

#pragma mark -
#pragma mark YLPieChartDelegate Methods
- (void)pieChartView:(YLPieChartView *)pieChartView willSelectSliceAtIndex:(NSUInteger)index {
    
}

- (void)pieChartView:(YLPieChartView *)pieChartView didSelectSliceAtIndex:(NSUInteger)index {
    NSLog(@"Did select slice: %d", index);
}

- (void)pieChartView:(YLPieChartView *)pieChartView willDeselectSliceAtIndex:(NSUInteger)index {
    
}

- (void)pieChartView:(YLPieChartView *)pieChartView didDeselectSliceAtIndex:(NSUInteger)index {
    NSLog(@"Did deselect slice: %d", index);
}

@end

