//
//  YLViewControlleriPhone.m
//  PieTouch
//
//  Created by Kemal Taskin on 10/2/12.
//  Copyright (c) 2012 Yakamoz Labs. All rights reserved.
//

#import "YLViewControlleriPhone.h"
#import "YLDemoOneViewController.h"
#import "YLDemoTwoViewController.h"
#import "YLDemoThreeViewController.h"
#import "YLDemoFourViewController.h"
#import <PieTouch/PieTouch.h>

@interface YLViewControlleriPhone () {
    NSTimer *_timer;
}

@end

@implementation YLViewControlleriPhone

@synthesize chartOne = _chartOne;
@synthesize chartTwo = _chartTwo;
@synthesize chartThree = _chartThree;
@synthesize labelOne = _labelOne;
@synthesize labelTwo = _labelTwo;
@synthesize labelThree = _labelThree;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if(self) {
        self.title = @"PieTouch SDK";

        _timer = nil;
    }
    
    return self;
}

- (void)dealloc {
    [_chartOne release];
    [_chartTwo release];
    [_chartThree release];
    [_labelOne release];
    [_labelTwo release];
    [_labelThree release];
    if(_timer) {
        [_timer invalidate];
    }
    
    [super dealloc];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    BOOL iPhone5 = [[UIScreen mainScreen] applicationFrame].size.height > 480;
    if(!iPhone5) {
        _labelOne.hidden = YES;
        _labelTwo.hidden = YES;
        _labelThree.hidden = YES;
    }
    
    NSArray *charts = [NSArray arrayWithObjects:_chartOne, _chartTwo, _chartThree, nil];
    for(YLPieSliceChartView *chart in charts) {
        if(!iPhone5) {
            CGRect frame = chart.frame;
            frame.origin.y = 0;
            chart.frame = frame;
        }
        chart.pieChartView.innerRadiusOffset = 0.5;
        chart.pieChartView.innerPieBackgroundColor = [UIColor clearColor];
        chart.pieChartView.pieBackgroundColor = [UIColor colorWithRed:0.7529 green:0.8706 blue:0.9686 alpha:1.0];
        chart.pieChartView.pieBorderColor = [UIColor colorWithWhite:0.0 alpha:0.5];
        chart.pieChartView.pieBorderWidth = 4.0;
        chart.pieChartView.textFont = [UIFont boldSystemFontOfSize:10.0];
        chart.pieChartView.textShadowColor = [UIColor blackColor];
        chart.sliceColor = [UIColor colorWithRed:0.2784 green:0.7216 blue:0.9882 alpha:1.0];
    }
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    
    if(_timer == nil) {
        _timer = [NSTimer scheduledTimerWithTimeInterval:2.0 target:self selector:@selector(updateChartValues) userInfo:nil repeats:YES];
    }
}

- (void)viewWillDisappear:(BOOL)animated {
    [super viewWillDisappear:animated];
    
    if(_timer) {
        [_timer invalidate];
        _timer = nil;
    }
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation {
    return UIInterfaceOrientationIsPortrait(toInterfaceOrientation);
}

- (BOOL)shouldAutorotate {
    return NO;
}

- (NSUInteger)supportedInterfaceOrientations {
    return UIInterfaceOrientationMaskPortrait;
}

- (void)updateChartValues {
    _chartOne.sliceValue = 0.4 + (arc4random() % 6 * 0.1);
    _chartTwo.sliceValue = 0.3 + (arc4random() % 6 * 0.1);
    _chartThree.sliceValue = 0.1 + (arc4random() % 3 * 0.1);
    
    [_chartOne reloadDataAnimated:YES];
    [_chartTwo reloadDataAnimated:YES];
    [_chartThree reloadDataAnimated:YES];
}


#pragma mark -
#pragma mark Instance Methods
- (IBAction)demoOne:(id)sender {
    YLDemoOneViewController *v = [[[YLDemoOneViewController alloc] init] autorelease];
    [self.navigationController pushViewController:v animated:YES];
}

- (IBAction)demoTwo:(id)sender {
    YLDemoTwoViewController *v = [[[YLDemoTwoViewController alloc] init] autorelease];
    [self.navigationController pushViewController:v animated:YES];
}

- (IBAction)demoThree:(id)sender {
    YLDemoThreeViewController *v = [[[YLDemoThreeViewController alloc] init] autorelease];
    [self.navigationController pushViewController:v animated:YES];
}

- (IBAction)demoFour:(id)sender {
    YLDemoFourViewController *v = [[[YLDemoFourViewController alloc] init] autorelease];
    [self.navigationController pushViewController:v animated:YES];
}

@end
