//
//  YLPieChartDataSource.h
//  PieTouch
//
//  Created by Kemal Taskin on 10/3/12.
//  Copyright (c) 2012 Yakamoz Labs. All rights reserved.
//

#import <Foundation/Foundation.h>

@class YLPieChartView;

/// You must implement this protocol to supply the necessary data information to YLPieChartView.
@protocol YLPieChartDataSource <NSObject>
@required
/// Return the number of slices in the pie chart.
/// @param pieChartView The YLPieChartView instance.
/// @returns Number of slices in the pie chart.
- (NSUInteger)numberOfSlicesInPieChartView:(YLPieChartView *)pieChartView;

/// Return the value for a specific pie slice. You don't need to worry about normalized values since
/// YLPieChartView will normalize the values internally while drawing the pie chart.
/// @param pieChartView The YLPieChartView instance.
/// @param index The pie slice index.
/// @returns Value for the pie slice.
- (CGFloat)pieChartView:(YLPieChartView *)pieChartView valueForSliceAtIndex:(NSUInteger)index;

@optional
/// Return the color that should be used for a specific pie slice. If you return nil or don't implement
/// this method YLPieChartView will auto-generate a color.
/// @param pieChartView The YLPieChartView instance.
/// @param index The pie slice index.
/// @returns Color for the pie slice.
- (UIColor *)pieChartView:(YLPieChartView *)pieChartView colorForSliceAtIndex:(NSUInteger)index;

/// Return YES if you only want to display a single pie slice. Have a look at YLPieSliceChartView how this
/// is used.
/// @param pieChartView The YLPieChartView instance.
/// @returns Boolean value that indicates wether only a single pie slice will be displayed.
- (BOOL)showSingleSliceInPieChartView:(YLPieChartView *)pieChartView;
@end
