//
//  YLPieSliceLayer.h
//  PieTouch
//
//  Created by Kemal Taskin on 10/2/12.
//  Copyright (c) 2012 Yakamoz Labs. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <QuartzCore/QuartzCore.h>

/// Layer that represents a single pie slice.
@interface YLPieSliceLayer : CAShapeLayer

/** @name Properties */
/// Value of this pie slice.
@property (nonatomic, assign) CGFloat value;

/// Normalized value (between 0.0 and 1.0) of this pie slice.
@property (nonatomic, assign) CGFloat normalizedValue;

/// Start angle in radians.
@property (nonatomic, assign) CGFloat startAngle;

/// End angle in radians.
@property (nonatomic, assign) CGFloat endAngle;

/// Boolean value that indicates wether the pie slice is selected or not.
@property (nonatomic, assign) BOOL selected;


/** @name Instance Methods */
/// Creates a CABasicAnimation for this layer.
/// @param key The key describing the property that should be animated.
/// @param fromValue The value describing where interpolation should start.
/// @param toValue The value describing where interpolation should end.
/// @param delegate Delegate that should be informed about animation events.
- (void)createAnimationForKey:(NSString *)key
                    fromValue:(NSNumber *)fromValue
                      toValue:(NSNumber *)toValue
                     delegate:(id)delegate;

@end
