PieTouch SDK for iOS
===

PieTouch SDK brings you native, delightful pie charts that you can use in your iOS applications. With just a few lines of code you can turn your data into interactive pie charts and change almost every aspect of their look and feel.

If you've used UITableView before you'll immediately pick up PieTouch SDK. The [API design](http://yakamozlabs.com/static/pietouch/index.html) is inspired by native iOS controls and consists of parts like data sources and delegates that you'll recognize immediately. There's also detailed [documentation](http://yakamozlabs.com/static/pietouch/index.html) that looks and feels like the original iOS docs.

<a href="http://bit.ly/PieTouch">![banner](http://dl.dropbox.com/u/1413757/PieTouch/banner.png)</a>

###You can purchase a license with the full source code at [Yakamoz Labs](http://yakamozlabs.com/products/pietouch).

## Code Documentation

All public classes of PieTouch SDK are documented using appledoc. See the [documentation](http://yakamozlabs.com/static/pietouch/index.html) for further information.

## Requirements

The source code of PieTouch SDK is developed on Xcode 4.5.1 with iOS Base SDK 6.0. PieTouch SDK works on a deployment target of iOS 5 or greater on armv7 and armv7s and can be used in ARC and non-ARC projects.

## Integration

- Drag PieTouch.framework into the "Frameworks" group of your Xcode project.
- Add the required libraries as shown in the screenshot below.
- Add the following import statement everywhere you want to use PieTouch SDK: **\#import \<PieTouch/PieTouch.h\>**

<a href="http://bit.ly/PieTouch">![integration](http://dl.dropbox.com/u/1413757/PieTouch/integration.png)</a>

## Sample Usage
    YLChartView *chartView = [[YLChartView alloc] initWithFrame:CGRectMake(0, 0, 200, 200)];
    [chartView setDataSource:self];
    [chartView setDelegate:self];
    [chartView setPieBackgroundColor:[UIColor colorWithHexString:@"999999"]];
    [chartView setPieBorderColor:[UIColor colorWithWhite:0.0 alpha:0.5]];
    [chartView setInnerPieBackgroundColor:[UIColor colorWithHexString:@"333333"]];
    [chartView setPieBorderWidth:4.0];
    [chartView setTextShadowColor:[UIColor blackColor]];
    [chartView setTextFont:[UIFont boldSystemFontOfSize:20]];
    [chartView setInnerRadiusOffset:60];
    [chartView setSelectionStyle:kSelectionStyleNoAnimation];
    [chartView setLabelStyle:kLabelStyleValue];
    [chartView setStartAngle:90];
    [chartView reloadData];


    YLPieSliceChartView *chart = [[YLPieSliceChartView alloc] initWithFrame:CGRectMake(0, 0, 100, 100)];
    chart.sliceColor = [UIColor colorWithHexString:@"23aae2"];
    chart.sliceValue = 0.6;
    [chart reloadData];
